@@ -280,6 +280,14 @@ config etc/X11/xdm/Xsession.new
 ( cd usr/X11R6/lib ; ln -sf libfontenc.so.1.0 libfontenc.so.1 )
 ( cd usr/X11R6/lib ; rm -rf libfontenc.so )
 ( cd usr/X11R6/lib ; ln -sf libfontenc.so.1.0 libfontenc.so )
+( cd usr/X11R6/lib ; rm -rf libxrx.so.6 )
+( cd usr/X11R6/lib ; ln -sf libxrx.so.6.8 libxrx.so.6 )
+( cd usr/X11R6/lib ; rm -rf libxrx.so )
+( cd usr/X11R6/lib ; ln -sf libxrx.so.6.8 libxrx.so )
+( cd usr/X11R6/lib ; rm -rf libxrxnest.so.6 )
+( cd usr/X11R6/lib ; ln -sf libxrxnest.so.6.8 libxrxnest.so.6 )
+( cd usr/X11R6/lib ; rm -rf libxrxnest.so )
+( cd usr/X11R6/lib ; ln -sf libxrxnest.so.6.8 libxrxnest.so )
 ( cd usr/X11R6/bin ; rm -rf X )
 ( cd usr/X11R6/bin ; ln -sf Xorg X )
 ( cd usr/X11R6/bin ; rm -rf inb )
@@ -340,7 +348,7 @@ config etc/X11/xdm/Xsession.new
 ( cd etc/X11/xkb/rules ; ln -sf xorg xfree86 )
 ( cd etc/X11/xkb/rules ; rm -rf xfree86.lst )
 ( cd etc/X11/xkb/rules ; ln -sf xorg.lst xfree86.lst )
-( cd etc/X11/xkb/rules ; rm -rf xfree86.xml )
-( cd etc/X11/xkb/rules ; ln -sf xorg.xml xfree86.xml )
 ( cd etc/X11/xkb/rules ; rm -rf xfree86-it.lst )
 ( cd etc/X11/xkb/rules ; ln -sf xorg-it.lst xfree86-it.lst )
+( cd etc/X11/xkb/rules ; rm -rf xfree86.xml )
+( cd etc/X11/xkb/rules ; ln -sf xorg.xml xfree86.xml )
